package com.takensoft.ai_lms.lms.board.service.impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.board.dao.BoardDAO;
import com.takensoft.ai_lms.lms.board.service.BoardService;
import com.takensoft.ai_lms.lms.board.vo.BoardStudentVO;
import com.takensoft.ai_lms.lms.board.vo.BoardVO;
import lombok.RequiredArgsConstructor;
import org.egovframe.rte.fdl.cmmn.EgovAbstractServiceImpl;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

@Service("boardService")
@RequiredArgsConstructor
public class BoardServiceImpl extends EgovAbstractServiceImpl implements BoardService {

    private final BoardDAO boardDAO;

    private final IdgenService boardIdgn;

    // 게시글 등록
    @Override
    public int insertBoard(BoardVO boardVO) throws Exception {
        String boardId = boardIdgn.getNextStringId();
        boardVO.setBbsId(boardId);
        int result = boardDAO.insertBoard(boardVO);

        if(result > 0) {
            BoardStudentVO boardStudentVO = new BoardStudentVO();
            boardStudentVO.setBbsId(boardId);
            boardDAO.insertBoardStudent(boardStudentVO);
        }

        return result;
    }
    // 게시글 전체 조회
    @Override
    public List<HashMap<String, Object>> findAllBoard(HashMap<String, Object> params) throws Exception {
        int page = Integer.parseInt(params.get("page").toString());
        int pageSize = Integer.parseInt(params.get("pageSize").toString());

        // 조회를 위한 startIndex 계산
        int startIndex = (page - 1) * pageSize;
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        System.out.println(startIndex);
        return boardDAO.findAllBoard(params);
    }

    // 전체 게시물 수 조회
    @Override
    public int boardCount(HashMap<String, Object> params) throws Exception {
        return boardDAO.boardCount(params);
    }


    // 게시글 상세 조회
    @Override
    public List<HashMap<String, Object>> findByBoardId(HashMap<String, Object> params) throws Exception {
        return boardDAO.findByBoardId(params);
    }

    // 게시글 수정
    @Override
    public int updateBoard(BoardVO boardVO) throws Exception {
        return boardDAO.updateBoard(boardVO);
    }

    // 게시글 삭제
    @Override
    public int deleteBoard(String bbsId) throws Exception{
        int result = boardDAO.deleteBoard(bbsId);

        if(result > 0) {
            boardDAO.deleteBoardStudent(bbsId);
        }

        return result;
    }

    // 게시글 검색
    @Override
    public List<HashMap<String, Object>> searchBoard(HashMap<String, Object> params) throws Exception {
        return boardDAO.searchBoard(params);
    }


    // 학생 게시판 등록
    @Override
    public int insertBoardStudent(BoardStudentVO boardStudentVO) throws Exception {
        return boardDAO.insertBoardStudent(boardStudentVO);
    }

    // 학생 게시판 삭세
    @Override
    public int deleteBoardStudent(String bbsId) throws Exception {
        return boardDAO.deleteBoardStudent(bbsId);
    }


    // 학생 게시판 조회
    @Override
    public List<BoardStudentVO> boardStudentList(HashMap<String, Object> params) throws Exception{
        int page = Integer.parseInt(params.get("page").toString());
        int pageSize = Integer.parseInt(params.get("pageSize").toString());

        // 조회를 위한 startIndex 계산
        int startIndex = (page - 1) * pageSize;
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        System.out.println(startIndex);
        return boardDAO.boardStudentList(params);
    }

    // 학생 게시판 수 조회
    @Override
    public int boardStudentCount(HashMap<String, Object> params) throws Exception {
        return boardDAO.boardStudentCount(params);
    }

    // 학생 게시판 조회 여부 체크
    @Override
    public int updateBoardCheck(HashMap<String, Object> params) throws Exception{
        return boardDAO.updateBoardCheck(params);
    }

    // 학생 게시판 조회 여부 일괄 갱신
    @Override
    public int updateAllBoardCheck(HashMap<String, Object> params) throws Exception{
        return boardDAO.updateAllBoardCheck(params);
    }

    // 학생 게시판 조회 안한 게시물 수 조회
    @Override
    public int checkCount(HashMap<String, Object> params) throws Exception{
        return boardDAO.checkCount(params);
    }



}
