package com.takensoft.ai_lms.lms.word_book.service.Impl;

import com.takensoft.ai_lms.common.idgen.service.IdgenService;
import com.takensoft.ai_lms.lms.word_book.dao.WordBookDAO;
import com.takensoft.ai_lms.lms.word_book.service.WordBookService;
import com.takensoft.ai_lms.lms.word_book.vo.WordBookVO;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

/**
 * @author 권민수
 * @since 2024.07.29
 *
 * 단어장 정보 관련 서비스
 */

@Service
@RequiredArgsConstructor
public class WordBookServiceImpl implements WordBookService {

    private final WordBookDAO wordBookDAO;

    private final IdgenService wordBookIdgn;

    @Override
    public List<WordBookVO> getAllWordBooks(int page, int pageSize) throws Exception {
        int startIndex = (page - 1) * pageSize;
        HashMap<String, Object> params = new HashMap<>();
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        return wordBookDAO.getAllWordBooks(params);
    }

    @Override
    public int getWordBooksCount() throws Exception {
        return wordBookDAO.getWordBooksCount();
    }

    @Override
    public List<WordBookVO> getWordBooksByBookId(String bookId, int page, int pageSize) throws Exception {
        int startIndex = (page - 1) * pageSize;
        HashMap<String, Object> params = new HashMap<>();
        params.put("bookId", bookId);
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        return wordBookDAO.getWordBooksByBookId(params);
    }

    @Override
    public int getWordBooksByBookIdCount(String bookId) throws Exception {
        return wordBookDAO.getWordBooksByBookIdCount(bookId);
    }

    @Override
    public WordBookVO getWordBookById(String wdBookId) {
        return wordBookDAO.getWordBookById(wdBookId);
    }

    @Override
    public void insertWordBook(WordBookVO wordBook) {
        String wdBookId = wordBookIdgn.getNextStringId();
        wordBook.setWdBookId(wdBookId);
        wordBookDAO.insertWordBook(wordBook);
    }

    @Override
    public void updateWordBook(WordBookVO wordBook) {
        wordBookDAO.updateWordBook(wordBook);
    }

    @Override
    public void deleteWordBook(String wdBookId) {
        wordBookDAO.deleteWordBook(wdBookId);
    }

    @Override
    public List<WordBookVO> getWordBooksByTextTitle(String textTitle, int page, int pageSize) throws Exception {
        int startIndex = (page - 1) * pageSize;
        HashMap<String, Object> params = new HashMap<>();
        params.put("textTitle", "%" + textTitle + "%");
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        return wordBookDAO.getWordBooksByTextTitle(params);
    }

    @Override
    public int getWordBooksByTextTitleCount(String textTitle) throws Exception {
        return wordBookDAO.getWordBooksByTextTitleCount(textTitle);
    }

    @Override
    public List<WordBookVO> getWordBooksByWord(String word, int page, int pageSize) throws Exception {
        int startIndex = (page - 1) * pageSize;
        HashMap<String, Object> params = new HashMap<>();
        params.put("word", word);
        params.put("startIndex", startIndex);
        params.put("pageSize", pageSize);
        return wordBookDAO.getWordBooksByWord(params);
    }

    @Override
    public int getWordBooksByWordCount(String word) throws Exception {
        return wordBookDAO.getWordBooksByWordCount(word);
    }

}
