package com.takensoft.ai_lms.lms.word_book.web;

import com.takensoft.ai_lms.lms.word_book.service.WordBookService;
import com.takensoft.ai_lms.lms.word_book.vo.WordBookVO;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author 권민수
 * @since 2024.07.29
 *
 * 단어장 정보 관련 컨트롤러 클래스
 */

@RestController
@RequiredArgsConstructor
@Slf4j
@RequestMapping("/wordbook")
public class WordBookController {

    final private WordBookService wordBookService;

    // 단어장 전체 목록 조회
    @PostMapping("/findAll.json")
    public HashMap<String, Object> getAllWordBooks(@RequestBody HashMap<String, Object> params) throws Exception {
        int page = (int) params.get("page");
        int pageSize = (int) params.get("pageSize");

        List<WordBookVO> wordBooks = wordBookService.getAllWordBooks(page, pageSize);
        int totalWordBooks = wordBookService.getWordBooksCount();

        HashMap<String, Object> result = new HashMap<>();
        result.put("wordBooks", wordBooks);
        result.put("totalWordBooks", totalWordBooks);

        return result;
    }

    // 책에 소속된 단어장 목록 조회
    @PostMapping("/findByBookId.json")
    public HashMap<String, Object> getWordBooksByBookId(@RequestBody HashMap<String, Object> params) throws Exception {
        String bookId = (String) params.get("bookId");
        int page = (int) params.get("page");
        int pageSize = (int) params.get("pageSize");

        List<WordBookVO> wordBooks = wordBookService.getWordBooksByBookId(bookId, page, pageSize);
        int totalWordBooks = wordBookService.getWordBooksByBookIdCount(bookId);

        HashMap<String, Object> result = new HashMap<>();
        result.put("wordBooks", wordBooks);
        result.put("totalWordBooks", totalWordBooks);

        return result;
    }

    // 아이디에 해당하는 단어장 조회
    @PostMapping("/find.json")
    public WordBookVO getWordBookById(@RequestBody WordBookVO wordBook) {
        return wordBookService.getWordBookById(wordBook.getWdBookId());
    }

    // 단어장 등록
    @PostMapping("/insert.json")
    public void insertWordBook(@RequestBody Map<String, String> req) {
        WordBookVO wordBook = new WordBookVO();
        wordBook.setWdBookTypeId(req.get("wdBookTypeId"));
        wordBook.setTextId(req.get("textId"));
        wordBook.setUserId(req.get("userId"));
        wordBook.setBookId(req.get("bookId"));
        wordBookService.insertWordBook(wordBook);
    }

    // 단어장 수정
    @PostMapping("/update.json")
    public void updateWordBook(@RequestBody WordBookVO wordBook) {
        wordBookService.updateWordBook(wordBook);
    }

    // 단어장 삭제
    @PostMapping("/delete.json")
    public void deleteWordBook(@RequestBody WordBookVO wordBook) {
        wordBookService.deleteWordBook(wordBook.getWdBookId());
    }

    // 단어장 검색(지문 이름으로 검색)
    @PostMapping("/findByTextTitle.json")
    public HashMap<String, Object> getWordBooksByTextTitle(@RequestBody HashMap<String, Object> params) throws Exception {
        String textTitle = (String) params.get("textTitle");
        int page = (int) params.get("page");
        int pageSize = (int) params.get("pageSize");

        List<WordBookVO> wordBooks = wordBookService.getWordBooksByTextTitle(textTitle, page, pageSize);
        int totalWordBooks = wordBookService.getWordBooksByTextTitleCount(textTitle);

        HashMap<String, Object> result = new HashMap<>();
        result.put("wordBooks", wordBooks);
        result.put("totalWordBooks", totalWordBooks);

        return result;
    }

    // 단어장 검색(단어로 검색)
    @PostMapping("/findByWord.json")
    public HashMap<String, Object> getWordBooksByWord(@RequestBody HashMap<String, Object> params) throws Exception {
        String word = (String) params.get("word");
        int page = (int) params.get("page");
        int pageSize = (int) params.get("pageSize");

        List<WordBookVO> wordBooks = wordBookService.getWordBooksByWord(word, page, pageSize);
        int totalWordBooks = wordBookService.getWordBooksByWordCount(word);

        HashMap<String, Object> result = new HashMap<>();
        result.put("wordBooks", wordBooks);
        result.put("totalWordBooks", totalWordBooks);

        return result;
    }

}
